@@ -155,6 +155,9 @@ class PerfilGrupo(core.models.Log):
     perfil = models.ForeignKey('sistema.Perfil', on_delete=models.DO_NOTHING, null=True)
     grupo = models.ForeignKey('usr.Grupo', on_delete=models.DO_NOTHING, null=True)
 
+    dat_ini = models.DateField(null=True)
+    dat_fim = models.DateField(null=True)
+
     class Meta(core.models.Log.Meta):
         abstract = False
         db_table = 'sistema_perfilgrupo'
